==> GADMTools_3.8-1.tar.gz: GADMTools/README.md <==
# GADMTools 

[![CRAN](https://www.r-pkg.org/badges/version/GADMTools)](https://CRAN.R-project.org/package=GADMTools) [![rpackages.io rank](https://www.rpackages.io/badge/GADMTools.svg)](https://www.rpackages.io/package/GADMTools) [![cran checks](https://cranchecks.info/badges/worst/GADMTools)](https://CRAN.R-project.org/web/checks/check_results_GADMTools.html)

[![Rdoc](http://www.rdocumentation.org/badges/version/GADMTools)](http://www.rdocumentation.org/packages/GADMTools)

## Downloads
[![](https://cranlogs.r-pkg.org/badges/grand-total/GADMTools?color=brightgreen)](https://cran.r-project.org/package=GADMTools)

[![](https://cranlogs.r-pkg.org/badges/GADMTools)](https://cran.r-project.org/package=GADMTools)
[![](https://cranlogs.r-pkg.org/badges/last-week/GADMTools)](https://cran.r-project.org/package=GADMTools)
[![](https://cranlogs.r-pkg.org/badges/last-day/GADMTools)](https://cran.r-project.org/package=GADMTools)

-----------------------------------------------------

GADMTools is an R package to manipulate shapefiles from GADM and to make geo-statistical representations easily. It supports *SpatialPolygonsDataFrame* and *sf* (Simple Features) formats from GADM database.

**GIT**: https://github.com/Epiconcept-Paris/GADMTools

## GADM

**GADM** is a spatial database of the world's adminstrative boundaries for use in **GIS** and similar software. Administrative areas in this database are countries and lower level subdivisions such as provinces, departments, cantons, etc.
Please, visit [gadm.org](https://gadm.org/) 

**NB:** https://gadm.org is not the creator nor the maintener nor responsable of **GADMTools**

## Easy use of GADM shapefiles

With **GADMTools**, a wrapper for **GADM** shapefiles, you can easily manipulate, assemble, create subsets of these objects and plot statistics on the final maps.

==> GADMTools_3.8-2.tar.gz: GADMTools/README.md <==
# GADMTools 

[![CRAN](https://www.r-pkg.org/badges/version/GADMTools)](https://CRAN.R-project.org/package=GADMTools) [![CRAN](https://www.r-pkg.org/badges/version-last-release/GADMTools)](https://CRAN.R-project.org/package=GADMTools)
[![cran checks](https://cranchecks.info/badges/worst/GADMTools)](https://CRAN.R-project.org/web/checks/check_results_GADMTools.html)

[![Rdoc](https://www.rdocumentation.org/badges/version/GADMTools/)](https://www.rdocumentation.org/packages/GADMTools/)

## Downloads

[![](https://cranlogs.r-pkg.org/badges/grand-total/GADMTools?color=brightgreen)](https://cran.r-project.org/package=GADMTools)

[![](https://cranlogs.r-pkg.org/badges/GADMTools)](https://cran.r-project.org/package=GADMTools)
[![](https://cranlogs.r-pkg.org/badges/last-week/GADMTools)](https://cran.r-project.org/package=GADMTools)
[![](https://cranlogs.r-pkg.org/badges/last-day/GADMTools)](https://cran.r-project.org/package=GADMTools)

-----------------------------------------------------

GADMTools is an R package to manipulate shapefiles from GADM and to make geo-statistical representations easily. It supports *SpatialPolygonsDataFrame* and *sf* (Simple Features) formats from GADM database.

**GIT**: https://github.com/IamKDO/GADMTools

## GADM

**GADM** is a spatial database of the world's adminstrative boundaries for use in **GIS** and similar software. Administrative areas in this database are countries and lower level subdivisions such as provinces, departments, cantons, etc.
Please, visit [gadm.org](https://gadm.org/) 

**NB:** https://gadm.org is not the creator nor the maintener nor responsable of **GADMTools**

## Easy use of GADM shapefiles

With **GADMTools**, a wrapper for **GADM** shapefiles, you can easily manipulate, assemble, create subsets of these objects and plot statistics on the final maps.
